==> airdcpp-webui-1.0.4.tgz: package/src/routes/Settings/routes/SpeedLimits/components/AutoValuePanel.jsx <==
import React from 'react';
import SettingForm from 'routes/Settings/components/SettingForm';
import { ChildFormMixin } from 'routes/Settings/mixins/SettingPageMixin';

import SocketService from 'services/SocketService';
import SettingConstants from 'constants/SettingConstants';


const AutoValuePanel = React.createClass({
	mixins: [ ChildFormMixin('form') ],
	propTypes: {
		/**
		 * Form items to list
		 */
		formItems: React.PropTypes.object.isRequired,

		/**
		 * Type of the value section (from the setting key)
		 */
		type: React.PropTypes.string.isRequired,
	},

	getAutoKey() {
		return this.props.type + '_auto_limits';
	},

	// Fetch auto settings when enabling auto detection
	onFieldChanged(changedKey, formValue, hasChanges) {
		const autoSettingKey = this.getAutoKey();
		if (changedKey !== autoSettingKey || !formValue[autoSettingKey]) {
			return null;
		}

		return SocketService.post(SettingConstants.ITEMS_INFO_URL, { 
			keys: Object.keys(this.props.formItems).filter(key => key !== autoSettingKey), 
			force_auto_values: true 
		});
	},

	// Disable other fields when auto detection is enabled
	onFieldSetting(settingKey, fieldOptions, formValue) {
		if (formValue[this.getAutoKey()] && settingKey !== this.getAutoKey()) {
			fieldOptions['disabled'] = true;
		}
	},

	render() {
		return (
			<div className="detection-settings ui segment">
				<SettingForm
					ref="form"
					formItems={ this.props.formItems }
					onFieldChanged={ this.onFieldChanged }
					onFieldSetting={ this.onFieldSetting }
				/>
			</div>
		);
	}
});

export default AutoValuePanel;

==> airdcpp-webui-1.1.2.tgz: package/src/routes/Settings/routes/SpeedLimits/components/AutoValuePanel.jsx <==
import React from 'react';
import SettingForm from 'routes/Settings/components/SettingForm';
import { ChildFormMixin } from 'routes/Settings/mixins/SettingPageMixin';

import SocketService from 'services/SocketService';
import SettingConstants from 'constants/SettingConstants';


const AutoValuePanel = React.createClass({
	mixins: [ ChildFormMixin('form') ],
	propTypes: {
		/**
		 * Form items to list
		 */
		formItems: React.PropTypes.object.isRequired,

		/**
		 * Type of the value section (from the setting key)
		 */
		type: React.PropTypes.string.isRequired,
	},

	getAutoKey() {
		return this.props.type + '_auto_limits';
	},

	// Fetch auto settings when enabling auto detection
	onFieldChanged(changedKey, formValue, hasChanges) {
		const autoSettingKey = this.getAutoKey();
		if (changedKey !== autoSettingKey || !formValue[autoSettingKey]) {
			return null;
		}

		return SocketService.post(SettingConstants.ITEMS_INFO_URL, { 
			keys: Object.keys(this.props.formItems).filter(key => key !== autoSettingKey), 
			force_auto_values: true 
		});
	},

	// Disable other fields when auto detection is enabled
	onFieldSetting(settingKey, fieldOptions, formValue) {
		if (formValue[this.getAutoKey()] && settingKey !== this.getAutoKey()) {
			fieldOptions['disabled'] = true;
		}
	},

	render() {
		return (
			<div className="ui segment">
				<SettingForm
					ref="form"
					formItems={ this.props.formItems }
					onFieldChanged={ this.onFieldChanged }
					onFieldSetting={ this.onFieldSetting }
				/>
			</div>
		);
	}
});

export default AutoValuePanel;
